@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
 our $DATE = '2016-06-28'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -324,11 +324,13 @@ sub __gen_table {
 
         my @res;
         push @res, "<table".($resmeta->{'table.html_class'} ?
-                                 "class=\"".HTML::Entities::encode_entities(
+                                 " class=\"".HTML::Entities::encode_entities(
                                      $resmeta->{'table.html_class'})."\"" : "").
                                          ">\n";
         for my $i (0..$#{$data}) {
             my $data_elem = $i == 0 ? "th" : "td";
+            push @res, "<thead>\n" if $i == 0;
+            push @res, "<tbody>\n" if $i == 1;
             push @res, " <tr>\n";
             my $row = $data->[$i];
             for my $j (0..$#{$row}) {
@@ -345,6 +347,8 @@ sub __gen_table {
                     "</$data_elem>\n";
             }
             push @res, " </tr>\n";
+            push @res, "</thead>\n" if $i == 0;
+            push @res, "</tbody>\n" if $i == 1;
         }
         push @res, "</table>\n";
         join '', @res;
@@ -452,7 +456,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.19 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-28.
+This document describes version 0.20 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-28.
 
 =head1 SYNOPSIS
 
